@@ -1,4 +1,4 @@
-use bson2::{Binary, Bson, to_bson};
+use rbson::{Binary, Bson, to_bson};
 use sqlx_core::column::Column;
 use sqlx_core::decode::Decode;
 use sqlx_core::error::BoxDynError;
@@ -12,8 +12,8 @@ use crate::convert::{JsonCodec, RefJsonCodec, ResultCodec};
 use chrono::{DateTime, Utc, NaiveDate};
 
 use crate::{to_bson_macro};
-use bson2::bson;
-use bson2::spec::BinarySubtype;
+use rbson::bson;
+use rbson::spec::BinarySubtype;
 use crate::db::db_adapter::DataDecoder;
 
 
@@ -93,7 +93,7 @@ impl<'r> JsonCodec for sqlx_core::mysql::MySqlValueRef<'r> {
             | "LONGTEXT" => {
                 let r: Option<Vec<u8>> = Decode::<'_, MySql>::decode(self)?;
                 if let Some(r) = r {
-                    return Ok(Bson::Binary(bson2::Binary {
+                    return Ok(Bson::Binary(rbson::Binary {
                         subtype: BinarySubtype::Generic,
                         bytes: r,
                     }));
@@ -151,7 +151,7 @@ impl<'r> JsonCodec for sqlx_core::mysql::MySqlValueRef<'r> {
                 //TODO "GEOMETRY" support. for now you can use already supported types to decode this
                 let r: Option<Vec<u8>> = Decode::<'_, MySql>::decode(self)?;
                 if let Some(r) = r {
-                    return Ok(Bson::Binary(bson2::Binary {
+                    return Ok(Bson::Binary(rbson::Binary {
                         subtype: BinarySubtype::Generic,
                         bytes: r,
                     }));
@@ -163,10 +163,10 @@ impl<'r> JsonCodec for sqlx_core::mysql::MySqlValueRef<'r> {
 }
 
 impl RefJsonCodec for Vec<MySqlRow> {
-    fn try_to_bson(&self, decoder: &dyn DataDecoder) -> crate::Result<bson2::Bson> {
+    fn try_to_bson(&self, decoder: &dyn DataDecoder) -> crate::Result<rbson::Bson> {
         let mut arr = Vec::with_capacity(self.len());
         for row in self {
-            let mut m = bson2::Document::new();
+            let mut m = rbson::Document::new();
             let columns = row.columns();
             for x in columns {
                 let key = x.name();
@@ -175,7 +175,7 @@ impl RefJsonCodec for Vec<MySqlRow> {
                 decoder.decode(key, &mut bson)?;
                 m.insert(key.to_owned(), bson);
             }
-            arr.push(bson2::Bson::Document(m));
+            arr.push(rbson::Bson::Document(m));
         }
         Ok(Bson::Array(arr))
     }
