@@ -1,3 +1,5 @@
+use std::any::{Any, type_name};
+use std::fmt::Debug;
 use std::ops::{Add, Deref, DerefMut};
 use std::str::FromStr;
 use std::time::SystemTime;
@@ -48,7 +50,12 @@ impl serde::Serialize for DateTimeNative {
                 self.inner.fmt(f)
             }
         }
-        return serializer.serialize_str(&format!("DateTimeNative({})", FormatWrapped { inner: &self }.to_string()));
+        use serde::ser::Error;
+        if type_name::<S::Error>().eq("rbson::ser::error::Error") {
+            return serializer.serialize_str(&format!("DateTimeNative({})", FormatWrapped { inner: &self }.to_string()));
+        } else {
+            return self.inner.serialize(serializer);
+        }
     }
 }
 
@@ -157,7 +164,7 @@ mod test {
     #[test]
     fn test_utc() {
         let dt = DateTimeNative::now();
-        println!("{}",dt);
+        println!("{}", dt);
         let s = rbson::to_bson(&dt).unwrap();
         let dt_new: DateTimeNative = rbson::from_bson(s).unwrap();
         println!("{},{}", dt.timestamp_millis(), dt_new.timestamp_millis());
@@ -176,8 +183,8 @@ mod test {
     fn test_ser_de() {
         let b = DateTimeNative::now();
         let bsons = rbson::to_bson(&b).unwrap();
-        println!("{}",bsons);
-        let b_de: DateTimeNative = rbson::from_bson(bsons).unwrap();
-        assert_eq!(b, b_de);
+        println!("{:?}", bsons);
+        let js = serde_json::to_value(&b).unwrap();
+        println!("{:?}", js);
     }
 }
\ No newline at end of file
